@@ -1,5 +1,5 @@
 package Config::IniFiles;
-$Config::IniFiles::VERSION = (qw($Revision: 1.13 $))[1];
+$Config::IniFiles::VERSION = (qw($Revision: 1.6 $))[1];
 use Carp;
 use strict;
 require 5.004;
@@ -10,8 +10,6 @@ require 5.004;
 
 Config::IniFiles - A module for reading .ini-style configuration files.
 
-     $Header: /cvsroot/config-inifiles/config-inifiles/IniFiles.pm,v 1.13 2000/11/28 12:41:42 grail Exp $
-
 =head1 SYNOPSIS
 
   use Config::IniFiles;
@@ -82,7 +80,7 @@ specify an array as the receiver:
 
 =head1 METHODS
 
-=head2 new ( [-option=>value ...] )
+=head2 new (-file=>$filename, [-option=>value ...] )
 
 Returns a new configuration object (or "undef" if the configuration
 file has an error).  One Config::IniFiles object is required per configuration
@@ -90,12 +88,6 @@ file.  The following named parameters are available:
 
 =over 10
 
-=item I<-file>  filename
-
-Specifies a file to load the parameters from. If this option is not specified, (ie:
-you are creating a config file from scratch) you must specify a target file
-using SetFileName in order to save the parameters.
-
 =item I<-default> section
 
 Specifies a section is used for default values.  For example, if you
@@ -282,11 +274,11 @@ sub newval {
   my $parm = shift;
   my @val  = @_;
 
-    push(@{$self->{sects}}, $sect) unless (grep /^\Q$sect\E$/, @{$self->{sects}});
+    push(@{$self->{sects}}, $sect) unless (grep /^$sect$/, @{$self->{sects}});
     $self->{v}{$sect} = {} unless ref $self->{v}{$sect} eq 'HASH';
 
     push(@{$self->{parms}{$sect}}, $parm) 
-      unless (grep /^\Q$parm\E$/,@{$self->{parms}{$sect}} );
+      unless (grep /^$parm$/,@{$self->{parms}{$sect}} );
 
   if (@val > 1) {
     $self->{v}{$sect}{$parm} = \@val;
@@ -309,7 +301,7 @@ sub delval {
   my $sect = shift;
   my $parm = shift;
 
-	@{$self->{parms}{$sect}} = grep !/^\Q$parm\E$/, @{$self->{parms}{$sect}};
+	@{$self->{parms}{$sect}} = grep !/^$parm$/, @{$self->{parms}{$sect}};
 	delete $self->{v}{$sect}{$parm};
 	return 1
 }
@@ -385,16 +377,16 @@ sub ReadConfig {
       push(@cmts, $_);
       next;
     }
-    elsif (/^\s*\[\s*(\S|\S.*\S)\s*\]\s*$/) {		# New Section
+    elsif (/^\s*\[(.*)\]\s*$/) {		# New Section
       $sect = $1;
       $sect = lc($sect) if $nocase;
       push(@{$self->{sects}}, $sect);
-      if ($sect =~ /(\S+)\s+\S+/) {		# New Group Member
-	$group = $1;
+      if ($sect =~ /(\S+)\s+(\S+)/) {		# New Group Member
+	($group, $groupmem) = ($1, $2);
 	if (!defined($self->{group}{$group})) {
 	  $self->{group}{$group} = [];
 	}
-	push(@{$self->{group}{$group}}, $sect);
+	push(@{$self->{group}{$group}}, $groupmem);
       }
       if (!defined($self->{v}{$sect})) {
 	$self->{sCMT}{$sect} = [@cmts] if @cmts > 0;
@@ -404,7 +396,7 @@ sub ReadConfig {
 	$self->{v}{$sect} = {};
       }
     }
-    elsif (($parm, $val) = /\s*([^=]+?)\s*=\s*(.*)/) {	# new parameter
+    elsif (($parm, $val) = /\s*([\S\s]+?)\s*=\s*(.*)/) {	# new parameter
       $parm = lc($parm) if $nocase;
       $self->{pCMT}{$sect}{$parm} = [@cmts];
       @cmts = ( );
@@ -668,7 +660,7 @@ sub SetSectionComment
 	my @comment = @_;
 
 	defined($section) || return undef;
-	@comment || return undef;
+	defined(@comment) || return undef;
 	
 	if (not exists $self->{sCMT}{$section}) {
 		$self->{sCMT}{$section} = [];
@@ -738,7 +730,7 @@ sub SetParameterComment
 
 	defined($section) || return undef;
 	defined($parameter) || return undef;
-	@comment || return undef;
+	defined(@comment) || return undef;
 	
 	if (not exists $self->{pCMT}{$section}) {
 		$self->{pCMT}{$section} = {};
@@ -1017,7 +1009,6 @@ sub FETCH {
 # Date      Modification                              Author
 # ----------------------------------------------------------
 # 2000Jun14 Fixed bug where wrong ref was saved           JW
-# 2000Oct09 Fixed possible but in %parms with defaults    JW
 # ----------------------------------------------------------
 sub STORE {
   my $self = shift;
@@ -1029,13 +1020,12 @@ sub STORE {
   $self->{v}{$key} = {};
 
   # Store the section name in the list
-  push(@{$self->{sects}}, $key) unless (grep /^\Q$key\E$/, @{$self->{sects}});
+  push(@{$self->{sects}}, $key) unless (grep /^$key$/, @{$self->{sects}});
 
   my %parms = %{$self->{startup_settings}};
   $self->{parms}{$key} = [];
   $parms{-parms} = $self->{parms}{$key};
   $parms{-_current_value} = $ref;
-  delete $parms{default};
   $parms{-default} = $self->{v}{$parms{-default}} if defined $parms{-default} && defined $self->{v}{$parms{-default}};
   tie %{$self->{v}{$key}}, 'Config::IniFiles::_section', %parms;
 } # end STORE
@@ -1050,7 +1040,7 @@ sub DELETE {
   my $self = shift;
   my( $key ) = @_;
 
-  @{$self->{sects}} = grep !/^\Q$key\E$/, @{$self->{sects}};
+  @{$self->{sects}} = grep !/^$key$/, @{$self->{sects}};
   return delete( $self->{v}{$key} );
 } # end DELETE
 
@@ -1124,7 +1114,7 @@ sub DESTROY {
 
 ############################################################
 #
-# INTERNAL PACKAGE: Config::IniFiles::_section
+# INTERAL PACKAGE: Config::IniFiles::_section
 #
 # Description:
 # This package is used to provide a single-level TIEHASH
@@ -1246,7 +1236,7 @@ sub STORE {
   my @val = @_;
 
   # Add the parameter the the parent's list if it isn't there yet
-  push(@{$self->{parms}}, $key) unless (grep /^\Q$key\E$/, @{$self->{parms}});
+  push(@{$self->{parms}}, $key) unless (grep /^$key$/, @{$self->{parms}});
 
   if (@val > 1) {
     $self->{v}{$key} = \@val;
@@ -1430,135 +1420,19 @@ Bernie Cosell, Alan Young, Alex Satrapa, Mike Blazer, Wilbert van de Pieterman,
 Steve Campbell, Robert Konigsberg, Scott Dellinger, R. Bernstein,
 Jeremy Wadsack, Daniel Winkelmann, Pires Claudio,  and Adrian Phillips.
 
-Geez, that's a lot of people. And apologies to the folks I missed.
+Geez, that's a lot of people.
 
 If you want someone to bug about this, that would be:
 
-	Rich Bowen <rbowen at rcbowen dot com>
+	Rich Bowen <rbowen@rcbowen.com>
 
 If you want more information, or want to participate, go to:
 
-	http://sourceforge.net/projects/config-inifiles/
+	http://dev.rcbowen.com/iniconf/
 
-Please send bug reports to config-inifiles-bugs@lists.sourceforge.net
-
-Development discussion occurs on the mailing list
-config-inifiles-dev@lists.sourceforge.net, which you can subscribe
-to by going to the project web site (link above).
+Please send bug reports to iniconf@rcbowen.com     
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
 
-=head1 Change log
-
-     $Log: IniFiles.pm,v $
-     Revision 1.13  2000/11/28 12:41:42  grail
-     Added test for being able to add sections with wierd names like section|version2
-
-     Revision 1.11  2000/11/24 21:20:11  rbowen
-     Resolved SourceForge bug #122445 - a parameter should be split from its value on the first = sign encountered, not on the last one. Added test suite to test this, and put test case in test.ini
-
-     Revision 1.10  2000/11/24 20:40:58  rbowen
-     Updated MANIFEST to have file list of new files in t/
-     Updated IniFiles.pm to have mention of sourceforge addresses, rather than rcbowen.com addresses
-     Regenerated README from IniFiles.pm
-
-     Revision 1.9  2000/11/23 05:08:08  grail
-     Fixed documentation for bug 122443 - Check that INI files can be created from scratch.
-
-     Revision 1.1.1.1  2000/11/10 03:04:01  rbowen
-     Initial checkin of the Config::IniFiles source to SourceForge
-
-     Revision 1.8  2000/10/17 01:52:55  rbowen
-     Patch from Jeremy. Fixed "defined" warnings.
-
-     Revision 1.7  2000/09/21 11:19:17  rbowen
-     Mostly documentation changes. I moved the change log into the POD rather
-     than having it in a separate Changes file. This allows people to see the
-     changes in the Readme before they download the module. Now I just
-     need to make sure I remember to regenerate the Readme every time I do
-     a commit.
-
-
-     1.6 September 19, 2000 by JW, AS
-     * Applied several patches submitted to me by Jeremy and Alex.
-     * Changed version number to the CVS version number, so that I won't
-     have to think about changing it ever again. Big version change
-     should not be taken as a huge leap forward.
-
-     0.12 September 13, 2000 by JW/WADG
-     * Added documentation to clarify autovivification issues when 
-     creating new sections
-     * Fixed version number (Oops!)
-
-     0.11 September 13, 2000 by JW/WADG
-     * Applied patch to Group and GroupMembers functions to return empty
-     list when no groups are present (submitted by John Bass, Sep 13)
-
-     0.10 September 13, 2000 by JW/WADG
-     * Fixed reference in POD to ReWriteFile. changes to RewriteConfig
-     * Applied patch for failed open bug submitted by Mordechai T. Abzug Aug 18
-     * Doc'd behavior of failed open
-     * Removed planned SIG testing from test.pl as SIGs have been removed
-     * Applied patch from Thibault Deflers to fix bug in parameter list
-     when a parameter value is undef
-
-     0.09
-     Hey! Where's the change log for 0.09?
-
-     0.08
-     2000-07-30  Adrian Phillips  <adrianp@powertech.no>
- 
-     * test.pl: Fixed some tests which use $\, and made those that try
-     to check a non existant val check against ! defined.
-
-     * IniFiles.pm: hopefully fixed use of $\ when this is unset
-     (problems found when running tests with -w).  Similar problem with
-     $/ which can be undefined and trying to return a val which does
-     not exist. Modified val docs section to indicate a undef return
-     when this occurs.
-
-     0.07
-     Looks like we missed a change log for 0.07. Bummer.
-
-     0.06 Sun Jun 25, 2000 by Daniel Winkelmann
-     * Patch for uninitialized value bug in newval and setval
-     
-     0.05 Sun Jun 18, 2000 by RBOW
-     * Added something to shut up -w on VERSIONS
-     * Removed unused variables
-
-     0.04 Thu Jun 15 - Fri Jun 16, 2000 by JW/WADG
-     * Added support for -import option on ->new
-     * Added support for tying a hash
-     * Edited POD for grammer, clarity and updates
-     * Updated test.pl file
-     * Fixed bug in multiline/single line output
-     * Fixed bug in default handling with tie interface
-     * Added bugs to test.pl for regression
-     * Fixed bug in {group} vs. {groups} property (first is valid)
-     * Fixed return value for empty {sects} or {parms}{$sect} in
-     Sections and Parameters methods
-
-     0.03 Thu Jun 15, 2000 by RBOW
-     * Modifications to permit 'use strict', and to get 'make test' working
-     again.
-
-     0.02 Tue Jun 13, 2000 by RBOW
-     * Fixed bug reported by Bernie Cosell - Sections, Parameters, 
-     and GroupMembers return undef if there are no sections,
-     parameters, or group members. These functions now return
-     () if the particular value is undefined.
-     * Added some contributed documentation, from Alex Satrapa, explaining
-     how the internal data structure works. 
-     * Set up a project on SourceForge. (Not a change, but worth
-     noting).
-     * Added Groups method to return a list of section groups.
-
-     0.01  Mon Jun 12, 2000 by RBOW
-     Some general code cleanup, in preparation for changes to
-     come. Put up Majordomo mailing list and sent invitation to
-     various people to join it.
-
 =cut
-
